View source: R/param-blur-sigmas.R
| blur_sigmas | R Documentation |
The standard deviation of the noise function convolved with array values to induce blur in raster data.
blur_sigmas(range = c(unknown(), unknown()), trans = transform_log1p())
range |
A two-element vector holding the defaults for the smallest and largest possible values, respectively. If a transformation is specified, these values should be in the transformed units. |
trans |
A |
The gaussian blur step deploys blur(). See there for definitions
and references.
get_blur_range() varies the parameter logarithmically from 0 to an order
of magnitude greater than the blur() default.
A param object or list of param objects.
img_dat <- data.frame(img = I(list(volcano)))
(blur_man <- blur_sigmas(range = c(0, 3)))
grid_regular(blur_man)
(blur_fin <- blur_sigmas() %>% get_blur_range(x = img_dat))
grid_regular(blur_fin)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.