| tdarec | R Documentation |
The tdarec package extends recipes and dials by providing pre-processing steps with tunable parameters for computing persistent homology of suitable data and for vectorizing persistent homology.
Maintainer: Jason Cory Brunson cornelioid@gmail.com
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.